package ch.phoenix.oss.quarkus.commons.client.logger;

import io.quarkus.rest.client.reactive.QuarkusRestClientBuilder;
import io.quarkus.test.junit.QuarkusTest;
import io.quarkus.test.junit.TestProfile;
import jakarta.inject.Inject;
import java.net.URI;
import java.util.Optional;
import org.eclipse.microprofile.rest.client.inject.RestClient;
import org.junit.jupiter.api.Test;

@QuarkusTest
@TestProfile(ScopeNoneProfile.class)
class ScopeNoneTest {

    @Inject
    @RestClient
    TestClient injectedClient;

    TestClient builtClient = QuarkusRestClientBuilder.newBuilder()
            .clientLogger(new RedactingClientLogger(() -> Optional::empty))
            .baseUri(URI.create("http://localhost:8087"))
            .build(TestClient.class);

    @Test
    void getWithInjectedClient() {
        injectedClient.get("this will be redacted", "5c0d8e45-e402-4b71-8f84-24cc0cfd7eec", "also redacted");
    }

    @Test
    void getWithBuiltClientAndEmptyConfig() {
        builtClient.get("this will be redacted", "5c0d8e45-e402-4b71-8f84-24cc0cfd7eec", "not redacted");
    }

    @Test
    void postWithInjectedClient() {
        injectedClient.post("this will be redacted", "5c0d8e45-e402-4b71-8f84-24cc0cfd7eec", "also redacted", "body");
    }

    @Test
    void postWithBuiltClientAndEmptyConfig() {
        builtClient.post("this will be redacted", "5c0d8e45-e402-4b71-8f84-24cc0cfd7eec", "not redacted", "");
    }
}
